@@ -28,18 +28,12 @@ logger = logging.getLogger(__name__)
 from not_so_tuf.client import Client
 from not_so_tuf.config import Config
 from not_so_tuf.downloader import FileDownloader
+from not_so_tuf.exceptions import NotSoTufError
+from not_so_tuf.filecrypt import FileCrypt
+from not_so_tuf.key_handler import KeyHandler
+from not_so_tuf.package_handler import PackageHandler
 from not_so_tuf.patcher import Patcher
-
-# Not used in client package.
-# Can safely ignore.
-try:
-    from not_so_tuf.exceptions import NotSoTufError
-    from not_so_tuf.filecrypt import FileCrypt
-    from not_so_tuf.key_handler import KeyHandler
-    from not_so_tuf.package_handler import PackageHandler
-    from not_so_tuf.uploader import Uploader
-except ImportError:
-    logger.info('Must be in client package.')
+from not_so_tuf.uploader import Uploader
 
 
 class NotSoTuf(object):
