@@ -70,7 +70,7 @@ class Client(object):
 
         # Grabbing config information
         self.update_url = self._fix_update_url(config.get('UPDATE_URL'))
-        self.app_name = config.get('APP_NAME')
+        self.app_name = config.get('APP_NAME', 'Not-So-TUF')
         self.data_dir = config.get('APP_DATA_DIR', None)
         self.public_key = config.get('PUBLIC_KEY', None)
         self.debug = config.get('DEBUG', False)
@@ -385,7 +385,7 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
             # update cycle.  If these keys weren't right an error would
             # have already been thrown.
             v = self.json_data[self.updates_key][name][self.highest_version]
-            _hash = v[platform_]['md5']
+            _hash = v[platform_]['file_hash']
             log.info('Downloading update...')
             fd = FileDownloader(filename, url, _hash)
             result = fd.download_verify_write()
