@@ -88,10 +88,10 @@ class PackageHandler(object):
     def setup(self):
         """Creates all needed working directories & loads version file.
 
-        Proxy method for :meth:`_setup_work_dirs` & :meth:`_load_json`
+        Proxy method for :meth:`_setup_work_dirs` & :meth:`_load_version_file`
         """
         self._setup_work_dirs()
-        self._load_json()
+        self._load_version_file()
 
     def update_package_list(self):
         """Gets a list of updates to process.  Adds the name of an
@@ -130,7 +130,7 @@ class PackageHandler(object):
             if not os.path.exists(d):
                 os.mkdir(d)
 
-    def _load_json(self):
+    def _load_version_file(self):
         # If version file is found its loaded to memory
         # If no version file is found then one is created.
         log.debug('Looking for version file...')
@@ -156,8 +156,12 @@ class PackageHandler(object):
         # Adds compatible packages to internal package manifest
         # for futher processing
         # Process all packages in new folder and gets
-        # url md5 and some outer info.
+        # url, hash and some outer info.
         log.info('Getting package list')
+        # Clears manifest if sign updates runs more the once without
+        # app being restarted
+        if len(self.package_manifest) != 0:
+            self.package_manifest = []
         bad_packages = []
         patch_manifest = []
         with ChDir(self.new_dir):
@@ -180,7 +184,7 @@ class PackageHandler(object):
                                 'name': p_name,
                                 'version': p_version,
                                 'filename': p,
-                                'md5': _hash,
+                                'file_hash': _hash,
                                 'platform': platform}
                 self.package_manifest.append(package_info)
                 path = self._check_make_patch(p_name, p_version, platform)
@@ -206,7 +210,7 @@ class PackageHandler(object):
                 for s in self.package_manifest:
                     if i[0] == s['real_name']:
                         s['patch_name'] = i[1]
-                        s['patch_md5'] = _get_package_hashes(i[1])
+                        s['patch_hash'] = _get_package_hashes(i[1])
                         break
         if ignore_errors is False:
             print 'Bad package names'
@@ -233,18 +237,18 @@ class PackageHandler(object):
         for p in self.package_manifest:
             version = p['version']
             name = p['name']
-            md5 = p['md5']
+            file_hash = p['file_hash']
             filename = p['filename']
             patch_name = p.get('patch_name', None)
-            patch_hash = p.get('patch_md5', None)
+            patch_hash = p.get('patch_hash', None)
 
             # Converting info to version file format
-            info = {'md5': md5,
+            info = {'file_hash': file_hash,
                     'url': self.update_url + p['real_name'],
                     'filename': filename}
             if patch_name and patch_hash:
                 info['patch_name'] = patch_name
-                info['patch_md5'] = patch_hash
+                info['patch_hash'] = patch_hash
                 info['patch_url'] = self.update_url + patch_name
 
             log.debug('json version {}'.format(self.json_data['updates']
