@@ -21,7 +21,6 @@
 # SOFTWARE.
 
 import bz2
-import hashlib
 import logging
 import os
 import sys
@@ -33,7 +32,8 @@ except ImportError:
 
 from not_so_tuf.compat import BytesIO
 from not_so_tuf.downloader import FileDownloader
-from not_so_tuf.utils import (ChDir, _version_string_to_tuple,
+from not_so_tuf.utils import (ChDir, _get_package_hashes,
+                              _version_string_to_tuple,
                               _version_tuple_to_string, platform_)
 
 
@@ -97,12 +97,12 @@ class Patcher(object):
         file_info = self._get_current_filename_and_hash(self.name,
                                                         self.current_version)
         filename = file_info['filename']
-        _hash = file_info['hash']
+        file_hash = file_info['file_hash']
         # I just really like using this ChDir context
         # manager.  Even sent the developer a cup of coffee
         with ChDir(self.update_folder):
-            file_hash = self._get_package_hashes(filename)
-            if _hash != file_hash:
+            installed_file_hash = _get_package_hashes(filename)
+            if file_hash != installed_file_hash:
                 log.warning('Binary hash mismatch')
                 return False
             if not os.path.exists(filename):
@@ -171,7 +171,7 @@ class Patcher(object):
             try:
                 info['patch_name'] = plat_info['patch_name']
                 info['patch_url'] = plat_info['patch_url']
-                info['patch_md5'] = plat_info['patch_md5']
+                info['patch_hash'] = plat_info['patch_hash']
                 self.patch_data.append(info)
             except KeyError:
                 log.error('Missing required patch meta-data')
@@ -183,7 +183,7 @@ class Patcher(object):
         log.debug('Downloading patches')
         for p in self.patch_data:
             fd = FileDownloader(p['patch_name'], p['patch_url'],
-                                p['patch_md5'])
+                                p['patch_hash'])
 
             data = fd.download_verify_return()
             if data is not None:
@@ -225,18 +225,9 @@ class Patcher(object):
             plat_info = self.json_data['y_data'][name][version][self.plat]
 
         info['filename'] = plat_info['filename']
-        info['hash'] = plat_info['md5']
+        info['hash'] = plat_info['file_hash']
         return info
 
-    def _get_package_hashes(self, package):
-        # Get hash of provided package
-        # Returns has of provided package
-        log.debug('Getting package hashes')
-        with open(package, 'rb') as f:
-            _hash = hashlib.md5(f.read()).hexdigest()
-            log.debug('Hash for file {}: {}'.format(package, _hash))
-        return _hash
-
 
 class bsdiff4_py(object):
     """Pure-python version of bsdiff4 module that can only patch, not diff.
