@@ -34,7 +34,6 @@ from not_so_tuf.exceptions import UploaderError
 from not_so_tuf.utils import _remove_hidden_stuff_mac
 from not_so_tuf.uploader.scp import ScpUploader
 from not_so_tuf.uploader.s3 import S3Uploader
-from not_so_tuf.uploader.sftp import SFTPUploader
 
 log = logging.getLogger(__name__)
 
@@ -141,12 +140,12 @@ class Uploader(object):
                              username=self.username,
                              password=self.password,
                              host=self.host)
+
             def failed_plugin_load(manager, entry_point, exception):
                 log.error('Could not load {}'.format(entry_point))
                 raise exception
             try:
-                mgr = driver.DriveManager(
-                                          namespace='not_so_tuf.uploader',
+                mgr = driver.DriveManager(namespace='not_so_tuf.uploader',
                                           name=requested_uploader.lower(),
                                           invoke_on_upload=True,
                                           invoke_kwds=info_dict
