@@ -27,7 +27,7 @@ import platform
 import struct
 import sys
 
-from not_so_tuf.compat import input_, print_function
+from not_so_tuf.compat import input_
 
 log = logging.getLogger(__name__)
 
@@ -47,9 +47,9 @@ if sys.platform == 'win32':
 elif sys.platform == 'darwin':
     platform_ = 'mac'
 else:
-    if platform.uname()[-1] == 'x86_64':
+    if 'x86_64' in platform.uname():
         platform_ = 'nix64'
-    elif platform.uname()[-1] != 'x86_64':
+    else:
         platform_ = 'nix'
 
 
@@ -110,9 +110,11 @@ def ask_yes_no(question, default='no', answer=None):
             log.debug('Must be false')
             return False
         else:
-            print('Please answer yes or no only!\n')
+            sys.stdout.write('Please answer yes or no only!\n\n')
+            sys.stdout.flush()
             input_('Press enter to continue')
-            print('\n\n\n\n')
+            sys.stdout.write('\n\n\n\n\n')
+            sys.stdout.flush()
 
 
 # Big Thanks to FiloSottile for making this lib for us
@@ -161,12 +163,21 @@ def rsa_verify(message, signature, key):
 
 def _get_package_hashes(filename):
         log.info('Getting package hashes')
+        filename = os.path.abspath(filename)
         with open(filename, 'rb') as f:
-            _hash = hashlib.md5(f.read()).hexdigest()
-            log.debug('Hash for file {}: {}'.format(filename, _hash))
+            data = f.read()
+
+        _hash = hashlib.sha256(data).hexdigest()
+        log.debug('Hash for file {}: {}'.format(filename, _hash))
         return _hash
 
 
+def _get_hash(data):
+    hash_ = hashlib.sha256(data).hexdigest()
+    log.debug('Hash for binary data: {}'.format(hash_))
+    return hash_
+
+
 def _remove_hidden_stuff_mac(files):
         # Removes hidden files from file list
         # ToDo: Implement a better way of handling this if there is one
